@@ -392,7 +392,16 @@ class HttpJwtAuthorizer(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpJwtAuthorizer.__init__)
+            def stub(
+                id: builtins.str,
+                jwt_issuer: builtins.str,
+                *,
+                jwt_audience: typing.Sequence[builtins.str],
+                authorizer_name: typing.Optional[builtins.str] = None,
+                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument jwt_issuer", value=jwt_issuer, expected_type=type_hints["jwt_issuer"])
         props = HttpJwtAuthorizerProps(
@@ -470,7 +479,14 @@ class HttpJwtAuthorizerProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpJwtAuthorizerProps.__init__)
+            def stub(
+                *,
+                jwt_audience: typing.Sequence[builtins.str],
+                authorizer_name: typing.Optional[builtins.str] = None,
+                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument jwt_audience", value=jwt_audience, expected_type=type_hints["jwt_audience"])
             check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
             check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
@@ -582,7 +598,17 @@ class HttpLambdaAuthorizer(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpLambdaAuthorizer.__init__)
+            def stub(
+                id: builtins.str,
+                handler: aws_cdk.aws_lambda.IFunction,
+                *,
+                authorizer_name: typing.Optional[builtins.str] = None,
+                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+                response_types: typing.Optional[typing.Sequence["HttpLambdaResponseType"]] = None,
+                results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
         props = HttpLambdaAuthorizerProps(
@@ -666,7 +692,15 @@ class HttpLambdaAuthorizerProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpLambdaAuthorizerProps.__init__)
+            def stub(
+                *,
+                authorizer_name: typing.Optional[builtins.str] = None,
+                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+                response_types: typing.Optional[typing.Sequence["HttpLambdaResponseType"]] = None,
+                results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
             check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
             check_type(argname="argument response_types", value=response_types, expected_type=type_hints["response_types"])
@@ -815,7 +849,17 @@ class HttpUserPoolAuthorizer(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpUserPoolAuthorizer.__init__)
+            def stub(
+                id: builtins.str,
+                pool: aws_cdk.aws_cognito.IUserPool,
+                *,
+                authorizer_name: typing.Optional[builtins.str] = None,
+                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+                user_pool_clients: typing.Optional[typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient]] = None,
+                user_pool_region: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument pool", value=pool, expected_type=type_hints["pool"])
         props = HttpUserPoolAuthorizerProps(
@@ -894,7 +938,15 @@ class HttpUserPoolAuthorizerProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpUserPoolAuthorizerProps.__init__)
+            def stub(
+                *,
+                authorizer_name: typing.Optional[builtins.str] = None,
+                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+                user_pool_clients: typing.Optional[typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient]] = None,
+                user_pool_region: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
             check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
             check_type(argname="argument user_pool_clients", value=user_pool_clients, expected_type=type_hints["user_pool_clients"])
@@ -1018,7 +1070,15 @@ class WebSocketLambdaAuthorizer(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(WebSocketLambdaAuthorizer.__init__)
+            def stub(
+                id: builtins.str,
+                handler: aws_cdk.aws_lambda.IFunction,
+                *,
+                authorizer_name: typing.Optional[builtins.str] = None,
+                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
         props = WebSocketLambdaAuthorizerProps(
@@ -1083,7 +1143,13 @@ class WebSocketLambdaAuthorizerProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(WebSocketLambdaAuthorizerProps.__init__)
+            def stub(
+                *,
+                authorizer_name: typing.Optional[builtins.str] = None,
+                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
             check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
         self._values: typing.Dict[str, typing.Any] = {}
